export declare const fatalErrorState = "FatalError";
export interface Header {
    StateMachineCode: number;
    ComponentCode: number;
    MessageType: string;
    PublishTopic: string;
    SessionData: string;
    StateMachineId: number;
    WorkerId: number;
    EventCode: number;
    IncomingEventType: number;
}
export interface Event {
    Header: Header;
    JsonMessage: string;
}
export interface Data {
    RoutingKey: string;
    ComponentCode: number;
    Event: Event;
}
export interface NameData {
    Name: string;
}
export interface EmptyData {
}
export interface TopicData {
    Header: Header;
    JsonMessage: string;
}
export interface CommandData {
    Command: string;
    Data: NameData | EmptyData | TopicData;
}
export interface Component {
    name: string;
    model: string;
    graphical: string;
}
export interface CompositionModel {
    projectName: string;
    components: Array<Component>;
    composition: string;
}
export interface DeserializedData {
    command: string;
    topic: string;
    stringData: string;
}
export declare let getHeaderWithIncomingType: () => Header;
export declare class Serializer {
    private logger;
    convertToWebsocketInputFormat(data: Data): string;
    convertCommandDataToWebsocketInputFormat(commandData: CommandData): string;
}
export declare class Deserializer {
    getJsonDataFromGetModelRequest(stringData: string): CompositionModel;
    decodeServerMessage(b64Data: string): string;
    getJsonDataFromXcApiRequest(data: string): string;
    getJsonDataFromGetXcApiListRequest(data: string): Array<string>;
    getJsonData(data: string): any;
    getPosition(str: string, subString: string, index: number): number;
    deserialize(data: string): DeserializedData;
    deserializeWithoutTopic(data: string): DeserializedData;
}
